@@ -102,7 +102,10 @@ on_word_wrap1_activate                 (GtkMenuItem     *menuitem,
     }
     
     setWordWrap = gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem));
-    gtk_text_view_set_wrap_mode(textBox, setWordWrap);
+    if(setWordWrap)
+        gtk_text_view_set_wrap_mode(textBox, GTK_WRAP_WORD);
+          else gtk_text_view_set_wrap_mode(textBox, GTK_WRAP_NONE);
+    gtk_text_view_set_justification( GTK_TEXT_VIEW(textBox), GTK_JUSTIFY_LEFT );
 }
 
 
@@ -163,13 +166,13 @@ on_set_highligting_colour1_activate    (GtkMenuItem     *menuitem,
     g_assert(dialog != NULL);
     g_assert(colorsel != NULL);
     
-    g_object_get( G_OBJECT(tag), "foreground-gdk", &cp, NULL);
+    g_object_get( G_OBJECT(tag), "background-gdk", &cp, NULL);
     gtk_color_selection_set_current_color(colorsel, cp);
     gdk_color_free(cp);
     if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
         GtkColorSelection *colorsel = GTK_COLOR_SELECTION(lookup_widget(dialog, "color_selection1"));
         gtk_color_selection_get_current_color(colorsel, &color);
-        g_object_set( G_OBJECT(tag), "foreground-gdk", &color, NULL);
+        g_object_set( G_OBJECT(tag), "background-gdk", &color, NULL);
     }
     gtk_widget_destroy(dialog);
 }
@@ -381,7 +384,7 @@ void
 on_contents1_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  SMsyscall(_("http://searchmonkey.sourceforge.net/index.php/SearchMonkey_User_Guide"), BROWSER_LIST);
+  SMsyscall(_("http://searchmonkey.embeddediq.com/index.php/contribute"), BROWSER_LIST);/* must ne changed, Luc A feb 2018 */
 }
 
 
@@ -389,7 +392,7 @@ void
 on_support1_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  SMsyscall(_("http://sourceforge.net/support/getsupport.php?group_id=175143"), BROWSER_LIST);
+  SMsyscall(_("http://searchmonkey.embeddediq.com/index.php/support"), BROWSER_LIST);
 }
 
 
@@ -405,7 +408,7 @@ on_about1_activate                     (GtkMenuItem     *menuitem,
   
   /* Set searchmonkey version text and font size */
   tmpWidget = lookup_widget(aboutDialog, "aboutVersion");
-  tmpString = g_strdup_printf(_("searchmonkey %s"), VERSION);
+  tmpString = g_strdup_printf(_("searchmonkey %s"), VERSION);/* defined in "configure" line 1644 - luc A 3 janv 2018 */
   gtk_label_set_text(GTK_LABEL(tmpWidget), tmpString);
   g_free(tmpString);
   list = pango_attr_list_new(); /* Create list with 1 reference */
@@ -448,7 +451,7 @@ on_containingText_changed              (GtkComboBox     *combobox,
     checkBox = GTK_TOGGLE_BUTTON(lookup_widget(GTK_WIDGET(combobox), "containingTextCheck2"));
   }
 
-  gchar *test = gtk_combo_box_get_active_text   (combobox);
+  gchar *test = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(combobox));
 
   if (test == NULL){
     gtk_toggle_button_set_active(checkBox, FALSE);
@@ -459,7 +462,7 @@ on_containingText_changed              (GtkComboBox     *combobox,
     } else {
       gtk_toggle_button_set_active(checkBox, TRUE);
     }
-    free(test);
+    g_free(test);
   }
 }
 
@@ -471,14 +474,14 @@ on_folderSelector_clicked              (GtkButton       *button,
   GtkWidget *dialog;
   GtkComboBox *fileWidget;
   gint result;
-  gchar *currentFolderName = gtk_combo_box_get_active_text(GTK_COMBO_BOX(lookup_widget(GTK_WIDGET(button), "lookIn")));
+  gchar *currentFolderName = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(lookup_widget(GTK_WIDGET(button), "lookIn")));
   
   dialog = create_folderChooserDialog();
   gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(dialog), currentFolderName);
   g_free(currentFolderName);
 
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
-    char *filename;
+    gchar *filename;
     
     filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
     if (getExpertSearchMode(GTK_WIDGET(button)) == TRUE) {
@@ -553,32 +556,67 @@ on_treeview1_button_press_event        (GtkWidget       *widget,
   GtkTreeView *treeview = GTK_TREE_VIEW(widget);
   GtkTreePath *path;
   GtkTreeViewDropPosition *pos;
-  GtkTreeSelection *selection = gtk_tree_view_get_selection (treeview);
-  
-  /* Capture right button click */
-  if ((event->button == 3) && (event->type == GDK_BUTTON_PRESS)) {
-    if (gtk_tree_view_get_path_at_pos (treeview,
-                                           event->x, event->y,
-                                           &path, NULL, NULL, NULL)) {
-      gtk_tree_selection_select_path (selection, path);
-      gtk_tree_path_free(path);
-      do_popup_menu(widget, event);
-    }
-    
-    return TRUE;
-    /* or double click detect */
-  } else if ((event->button == 1) && (event->type == GDK_2BUTTON_PRESS)) {
-    gchar *fullFileName = getFullFileName(treeview, FULL_FILENAME_COLUMN);
-    
-    if (fullFileName != NULL) {
-      SMsyscall(fullFileName, TEXTEDITOR_LIST);
-      g_free(fullFileName);
-    }
-    return TRUE;
-  }
-  
 
-  return FALSE;
+
+  GtkTreeSelection *selection = gtk_tree_view_get_selection (treeview);
+
+  if(selection==NULL)
+     return FALSE;
+  /* Capture right button click */
+  if ((event->button == 3) && (event->type == GDK_BUTTON_PRESS) && (gtk_tree_selection_count_selected_rows(selection)==1 ) ) 
+   {
+    if (gtk_tree_view_get_path_at_pos (treeview,
+                                       event->x, event->y,
+                                       &path, NULL, NULL, NULL)) 
+     {
+       // gtk_tree_selection_unselect_all(selection); /* added by Luc A., 28 dec 2017 */
+       gtk_tree_selection_select_path (selection, path);
+       if (path!=NULL) 
+         {
+          gtk_tree_path_free(path);
+         }/* if path!=NULL */
+       do_popup_menu(widget, event);
+       return TRUE;
+     }/* if test path at pos OK */   
+    else return FALSE;
+   }/* endif right-click */ 
+/* capture double-click */
+ if ((event->button == 1) && (event->type == GDK_2BUTTON_PRESS) && (gtk_tree_selection_count_selected_rows(selection)==1 )) 
+   {
+     if (gtk_tree_view_get_path_at_pos (treeview,event->x, event->y,
+                                    &path, NULL, NULL, NULL)) 
+      {
+          gchar *fullFileName = getFullFileName(treeview, FULL_FILENAME_COLUMN);
+          if (fullFileName != NULL) 
+            {
+              SMsyscall(fullFileName, TEXTEDITOR_LIST);
+              g_free(fullFileName);
+            }
+          return TRUE;
+      }/* endif at pos */
+    }/* endif double-click */
+   
+/* capture simple-left-click, i.e. select a row */
+ if ((event->button == 1) && (event->type == GDK_BUTTON_PRESS)  && (gtk_tree_selection_count_selected_rows(selection)==1 )) 
+   {
+     if (gtk_tree_view_get_path_at_pos (treeview,event->x, event->y,
+                                    &path, NULL, NULL, NULL)) 
+      {
+            gtk_tree_selection_unselect_all(selection); /* ajout */
+            if (gtk_tree_selection_count_selected_rows(selection)==1)
+             {
+               gtk_tree_selection_select_path (selection, path);
+               if (path!=NULL) 
+                {
+		 // printf("* avant libère mémoire *\n");
+                 gtk_tree_path_free(path);
+                 // printf("* après libère mémoire *\n");
+                }    
+              return TRUE;
+             }
+      }
+   }/* endif left-click */
+ return FALSE;
 }
 
 
@@ -587,7 +625,7 @@ on_treeview1_popup_menu                (GtkWidget       *widget,
                                         gpointer         user_data)
 {
   do_popup_menu(widget, NULL);
-  return TRUE;
+  return FALSE;
 }
 
 
@@ -689,9 +727,7 @@ on_SampleTextView_realize              (GtkWidget       *widget,
   GtkTextTag *tag;
   
   tag = gtk_text_buffer_create_tag (buffer, "word_highlight",
-                                    "foreground", "blue",
-                                    "underline", PANGO_UNDERLINE_SINGLE,
-                                    "underline-set", TRUE,
+                                    "foreground", "black","background", "lightBlue",
                                     NULL);
 #ifdef NOT_YET
   tag = gtk_text_buffer_create_tag (buffer, "word_highlight1",
@@ -706,13 +742,13 @@ on_expWizard_response                  (GtkDialog       *dialog,
                                         gint             response_id,
                                         gpointer         user_data)
 {
-    gint typeRegex = (gint)g_object_get_data(G_OBJECT(dialog), "regexType");
-    GtkEntry *output = GTK_ENTRY(lookup_widget(GTK_WIDGET(dialog), "resultExp"));
+    gint typeRegex = (intptr_t)g_object_get_data(G_OBJECT(dialog), "regexType");
+    GtkEntry *output = GTK_ENTRY(lookup_widget(GTK_WIDGET(dialog), "resultExp"));/* resulExp = name of GtkEntry for the final RegEx formula */
     gchar *finalRegex;
-    GtkComboBox *retCombo;
+    GtkComboBox *retCombo;/* contains a pointer on main Window, for GtkCombo for files OR GtkCombo for containing text */
     
     if (typeRegex == FILE_REGEX_TYPE) {
-        retCombo = GTK_COMBO_BOX(lookup_widget(mainWindowApp, "fileName"));
+        retCombo = GTK_COMBO_BOX(lookup_widget(mainWindowApp, "fileName"));/* filename = GtkWidget, field of the combo in main window */
     } else if (typeRegex == CONTEXT_REGEX_TYPE) {
         retCombo = GTK_COMBO_BOX(lookup_widget(mainWindowApp, "containingText"));
     } else {
@@ -722,15 +758,16 @@ on_expWizard_response                  (GtkDialog       *dialog,
     }
     
     switch (response_id) {
-        case GTK_RESPONSE_OK:
-            finalRegex = (gchar *)gtk_entry_get_text(output);
-            if (*finalRegex != '\0') {
-                addUniqueRow(GTK_WIDGET(retCombo), finalRegex);
-            }
-            /* Do not break here! We want the widget to be destroyed! */
         case GTK_RESPONSE_HELP:
             SMsyscall(_("http://searchmonkey.sourceforge.net/index.php/Regular_expression_builder"), BROWSER_LIST);
             break;
+        case GTK_RESPONSE_OK:
+            finalRegex = (gchar *)gtk_entry_get_text(output);/* read text in Wizard dialog, resulting formula */
+            if (*finalRegex != '\0') {
+                addUniqueRow(GTK_WIDGET(retCombo), finalRegex);/* modify combobox in main window */
+            }
+            /* Do not break here! We want the widget to be destroyed! */
+
         default:
             if (typeRegex == FILE_REGEX_TYPE) {
                 fileRegexWizard = NULL;
@@ -875,9 +912,9 @@ on_addMidContents_clicked              (GtkButton       *button,
     
     appendTableRow(lookup_widget(GTK_WIDGET(button), "midTreeView"),
                    5,
-                   gtk_combo_box_get_active_text(type),
+                   gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(type)),
                    gtk_entry_get_text(entry),
-                   gtk_combo_box_get_active_text(repeat),
+                   gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(repeat)),
                    gtk_combo_box_get_active(type),
                    gtk_combo_box_get_active(repeat));
     gtk_combo_box_set_active(type, 0);
@@ -954,7 +991,7 @@ on_deleteSelectedContents_clicked      (GtkButton       *button,
   updateRegExWizard(GTK_WIDGET(button));
 }
 
-
+/* Regex Wizard : middle part of the expression */
 void
 on_midTreeView_realize                 (GtkWidget       *widget,
                                         gpointer         user_data)
@@ -962,7 +999,7 @@ on_midTreeView_realize                 (GtkWidget       *widget,
     GtkTreeViewColumn *column;
     GtkCellRenderer *renderer = gtk_cell_renderer_text_new ();
 
-    GtkListStore *store = gtk_list_store_new (REGEX_N_COLUMNS,
+    GtkListStore *store = gtk_list_store_new (REGEX_N_COLUMNS,/* number of total columns in Regex wizard- 1 janv 2018 Luc A*/                                            
                                               G_TYPE_STRING,
                                               G_TYPE_STRING,
                                               G_TYPE_STRING,
@@ -973,17 +1010,17 @@ on_midTreeView_realize                 (GtkWidget       *widget,
     g_object_unref (G_OBJECT (store));
 
     /* Create columns */
-    column = gtk_tree_view_column_new_with_attributes ("_(Type)", renderer,
+    column = gtk_tree_view_column_new_with_attributes (_("(Type)"), renderer,
                                                        "text", REGEX_TYPE_COLUMN,
                                                        NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (widget), column);
 
-    column = gtk_tree_view_column_new_with_attributes ("_(Entry)", renderer,
+    column = gtk_tree_view_column_new_with_attributes (_("(Entry)"), renderer,
                                                        "text", REGEX_ENTRY_COLUMN,
                                                        NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (widget), column);
 
-    column = gtk_tree_view_column_new_with_attributes ("_(Repeat)", renderer,
+    column = gtk_tree_view_column_new_with_attributes (_("(Repeat)"), renderer,
                                                        "text", REGEX_REPEAT_COLUMN,
                                                        NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (widget), column);
@@ -1030,9 +1067,9 @@ on_updateSelectedContents_clicked      (GtkButton       *button,
   }
     
   gtk_list_store_set (GTK_LIST_STORE(model), &iter,
-                      REGEX_TYPE_COLUMN, gtk_combo_box_get_active_text(type),
+                      REGEX_TYPE_COLUMN, gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(type)),
                       REGEX_ENTRY_COLUMN, gtk_entry_get_text(entry),
-                      REGEX_REPEAT_COLUMN, gtk_combo_box_get_active_text(repeat),
+                      REGEX_REPEAT_COLUMN, gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(repeat)),
                       REGEX_TYPE_INT_COLUMN, gtk_combo_box_get_active(type),
                       REGEX_REPEAT_INT_COLUMN, gtk_combo_box_get_active(repeat),
                       -1);
@@ -1062,7 +1099,7 @@ void
 on_expWizard_realize                   (GtkWidget       *widget,
                                         gpointer         user_data)
 {
-  gint widgetType = (gint)g_object_get_data(G_OBJECT(widget), "regexType");
+  gint widgetType = (intptr_t)g_object_get_data(G_OBJECT(widget), "regexType");
 
   if (widgetType == FILE_REGEX_TYPE) {
     gtk_window_set_title (GTK_WINDOW (fileRegexWizard), _("File Expression Wizard"));
@@ -1122,7 +1159,7 @@ on_online_release_notes1_activate      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
   /* Browse to a new release notes subset. Note redirect required by website */
-  gchar *website = g_strdup_printf(_("http://%s.sf.net/index.php?title=V%s_Release_Notes"), PACKAGE, VERSION);
+  gchar *website = g_strdup_printf(_("https://sourceforge.net/projects/searchmonkey/files/gSearchmonkey%20GTK%20%28Gnome%29/0.8.2%20%5Bstable%5D/"), PACKAGE, VERSION);
   SMsyscall(website, BROWSER_LIST);
 }
 
@@ -1172,7 +1209,7 @@ void
 on_forums1_activate                    (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  SMsyscall(_("http://sf.net/forum/?group_id=175143"), BROWSER_LIST);
+  SMsyscall(_("http://searchmonkey.embeddediq.com/index.php/support/index"), BROWSER_LIST);
 }
 
 
@@ -1399,20 +1436,55 @@ on_autosize_columns_activate           (GtkMenuItem     *menuitem,
   realizeTreeviewColumns (GTK_WIDGET(mainWindowApp), keyString, "history", "treeview", autoColumnWidth);  
 }
 
+/* surprise : menu empty at last 2017
+ so I've made the job - :-) Luc A. - 4 janv 2018
+*/
+
 
 void
 on_edit_file1_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+ GtkTreeView *treeView;
+ gchar *fullFileName;
+  
+  if (getResultsViewHorizontal(GTK_WIDGET(menuitem))) {
+    treeView = GTK_TREE_VIEW(lookup_widget(GTK_WIDGET(menuitem), "treeview1"));
+  } else {
+    treeView = GTK_TREE_VIEW(lookup_widget(GTK_WIDGET(menuitem), "treeview2"));
+  }
+  fullFileName = getFullFileName(treeView, FULL_FILENAME_COLUMN);
+
+  if (fullFileName != NULL) {
+    SMsyscall(fullFileName, TEXTEDITOR_LIST);
+    g_free(fullFileName);
+  }
 
 }
 
+/* surprise : menu empty at last 2017
+ so I've made the job - :-) Luc A. - 4 janv 2018
+*/
+
 
 void
 on_open_folder1_activate               (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+ GtkTreeView *treeView;
+  gchar *location;
+  
+  if (getResultsViewHorizontal(GTK_WIDGET(menuitem))) {
+    treeView = GTK_TREE_VIEW(lookup_widget(GTK_WIDGET(menuitem), "treeview1"));
+  } else {
+    treeView = GTK_TREE_VIEW(lookup_widget(GTK_WIDGET(menuitem), "treeview2"));
+  }
+  location = getFullFileName(treeView, LOCATION_COLUMN);
 
+  if (location != NULL) {
+    SMsyscall(location, FILEEXPLORER_LIST);
+    g_free(location);
+  }
 }
 
 
@@ -1443,9 +1515,20 @@ void
 on_dosExpressionRadioFile_clicked      (GtkButton       *button,
                                         gpointer         user_data)
 {
+  GtkStatusbar *statusbar = GTK_STATUSBAR(lookup_widget(GTK_WIDGET(button), "statusbar1"));
+
+
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button))) {
     changeModel(GTK_WIDGET(button), "regex", "noregex");
   }
+  gtk_statusbar_pop(statusbar, STATUSBAR_CONTEXT_ID(statusbar));  
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (lookup_widget(GTK_WIDGET(button), "dosExpressionRadioFile"))))
+    {        
+        gtk_statusbar_push(statusbar, STATUSBAR_CONTEXT_ID(statusbar),
+                     _("research mode with jokers(DOS like)"));
+    }
+  else  gtk_statusbar_push(statusbar, STATUSBAR_CONTEXT_ID(statusbar),
+                     _("research mode with RegEx")); 
 }
 
 
@@ -1480,6 +1563,30 @@ on_beforeCalendatBtn_clicked           (GtkButton       *button,
   g_free(newDate);
 }
 
+/* Luc A - janv 2018 */
+gboolean
+on_LessThanSize_focus_out_event         (GtkWidget       *widget,
+                                        GdkEventFocus   *event,
+                                        gpointer         user_data)
+{
+  gchar * regexp;
+  guint flags;
+  // printf("combo Less changée \n");  
+  return FALSE;
+}
+
+/* Luc A - janv 2018 */
+gboolean
+on_MoreThanSize_focus_out_event         (GtkWidget       *widget,
+                                        GdkEventFocus   *event,
+                                        gpointer         user_data)
+{
+  gchar * regexp;
+  guint flags;
+  // printf("combo More changée \n");
+  return FALSE;
+}
+
 
 gboolean
 on_regexp_focus_out_event              (GtkWidget       *widget,
@@ -1496,7 +1603,7 @@ on_regexp_focus_out_event              (GtkWidget       *widget,
     }
     flags |= REG_NOSUB;
 
-    regexp = gtk_combo_box_get_active_text(GTK_COMBO_BOX(widget));
+    regexp = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(widget));
   
     if (test_regexp(regexp, flags, error)) {
       addUniqueRow(widget, regexp);
@@ -1519,7 +1626,7 @@ on_regexp2_focus_out_event             (GtkWidget       *widget,
   }
   flags |= REG_NOSUB;
 
-  regexp = gtk_combo_box_get_active_text(GTK_COMBO_BOX(widget));
+  regexp = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(widget));
   
   if (test_regexp(regexp, flags, error)) {
     addUniqueRow(widget, regexp);
