@@ -15,6 +15,49 @@
 #include "misc.h"
 #include <regex.h>
 
+/****************************************************
+  display an erreor/warning dialog
+****************************************************/
+void miscErrorDialog(GtkWidget *widget, const gchar* msg)
+{ 
+GtkWidget *dialog;
+
+   dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW(widget),
+                                           GTK_DIALOG_DESTROY_WITH_PARENT,
+                                           GTK_MESSAGE_ERROR,
+                                           GTK_BUTTONS_CLOSE,
+                                           msg);
+   gtk_dialog_run (GTK_DIALOG (dialog));
+   gtk_widget_destroy (dialog);
+}
+/********************************************************************************************
+  convert a regex byte position in a string to
+  a gtk gchar compatible position - 
+  Luc A janv 2018
+  entry1 = offset means the offset computed by regex function, with multubytes chars
+  entre2 = contents = the string returned by regex
+  output = the "true" gchar position compatible with Gtk   
+*******************************************************************************************/
+gint convertRegexGtk(size_t offset, const gchar *contents)
+{
+ gint count = 0;
+ gint len =0;
+ gint i=0;
+ size_t max = offset;
+
+ while(max>0)
+   {
+      len = mblen(contents, max);
+      if (len<1) break;
+      //printf(">>> %c  <<<<", contents[i]);
+      i++;
+      contents+=len; 
+      max-=len;
+   }
+ count = i;
+ return count;
+}
+
 
 /*
  * callback/internal helper: returns the text stored within supplied columnNumber
@@ -237,7 +280,7 @@ void copySettings(GtkWidget *widget, gboolean expertMode)
 	source = 1;
 	target = 0;
     }
-    tmpString = gtk_combo_box_get_active_text(GTK_COMBO_BOX(filename[source]));
+    tmpString = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(filename[source]));
     if (getExtendedRegexMode(widget)) {
       tmpFlags |= REG_EXTENDED;
     }
@@ -251,14 +294,14 @@ void copySettings(GtkWidget *widget, gboolean expertMode)
     
     gtk_toggle_button_set_active(containingTextCheck[target],gtk_toggle_button_get_active(containingTextCheck[source]));
     
-    tmpString = gtk_combo_box_get_active_text(GTK_COMBO_BOX(containingText[source]));
+    tmpString = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(containingText[source]));
     if (test_regexp(tmpString, tmpFlags, _("Error! Invalid Containing Text regular expression"))) {
       addUniqueRow(containingText[target], tmpString);
       addUniqueRow(containingText[source], tmpString);
     }
     g_free(tmpString);
 
-    tmpString = gtk_combo_box_get_active_text(GTK_COMBO_BOX(lookin[source]));
+    tmpString = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(lookin[source]));
     if (validate_folder(tmpString)) {
       addUniqueRow(lookin[target], tmpString);
       addUniqueRow(lookin[source], tmpString);
@@ -284,7 +327,8 @@ void setExpertSearchMode (GtkWidget *widget, gboolean expertMode)
 gboolean getExpertSearchMode (GtkWidget *widget)
 {
   GtkWidget *searchNotebook = lookup_widget(widget, "searchNotebook");
-  if (gtk_notebook_get_current_page(GTK_NOTEBOOK(searchNotebook)) == 1) {
+  /* modified by Luc A - if the current page == option, then all options are deactivated !!! FIXED janv 2018 */
+  if (gtk_notebook_get_current_page(GTK_NOTEBOOK(searchNotebook)) != 0) {
     return TRUE;
   } else {
     return FALSE;
@@ -293,7 +337,13 @@ gboolean getExpertSearchMode (GtkWidget *widget)
 
 void sel (GtkTreeModel *model, GtkTreePath *path,GtkTreeIter *iter, gpointer data)
 {
-  gtk_tree_selection_select_path((GtkTreeSelection *)data, path);
+ GtkTreeSelection *tmpTreeSelection = NULL;
+
+ tmpTreeSelection = (GtkTreeSelection *)data;
+
+if((tmpTreeSelection!=NULL) && (model!=NULL)  && (path!=NULL))
+    gtk_tree_selection_select_path(tmpTreeSelection, path);
+
 }
 
 /*
@@ -304,15 +354,20 @@ void setResultsViewHorizontal(GtkWidget *widget, gboolean horizontal)
   GtkTreeSelection *treeview1 = gtk_tree_view_get_selection(GTK_TREE_VIEW(lookup_widget(widget, "treeview1")));
   GtkTreeSelection *treeview2 = gtk_tree_view_get_selection(GTK_TREE_VIEW(lookup_widget(widget, "treeview2")));
 
-  if (horizontal) {
-    gtk_widget_show(lookup_widget(widget, "resultsHPane"));
-    gtk_widget_hide(lookup_widget(widget, "resultsVPane"));
-    gtk_tree_selection_selected_foreach(treeview2, &sel, treeview1);
-  } else { /* Vertical - default */
-    gtk_widget_hide(lookup_widget(widget, "resultsHPane"));
-    gtk_widget_show(lookup_widget(widget, "resultsVPane"));
-    gtk_tree_selection_selected_foreach(treeview1, &sel, treeview2);
-  }
+  if((treeview1!=NULL)&&(treeview2!=NULL))
+   {
+      /* we must chek if selection != NULL - Luc A feb 2018 */
+
+     if (horizontal) {
+       gtk_widget_show(lookup_widget(widget, "resultsHPane"));
+       gtk_widget_hide(lookup_widget(widget, "resultsVPane"));
+       gtk_tree_selection_selected_foreach(treeview2, &sel, treeview1);
+    } else { /* Vertical - default */
+            gtk_widget_hide(lookup_widget(widget, "resultsHPane"));
+            gtk_widget_show(lookup_widget(widget, "resultsVPane"));
+            gtk_tree_selection_selected_foreach(treeview1, &sel, treeview2);
+           }
+   }/* if treeview!=NULL*/
 }
 
 
@@ -389,8 +444,8 @@ gchar *getDate(const gchar *curDate)
     gtk_calendar_get_date(calendar, &year, &month, &day);
     gtk_widget_destroy(calendarDialog);
 
-    result = (gchar *)g_malloc(sizeof(gchar) * 12);
-    g_date_strftime(result, 11, "%d %b %y", g_date_new_dmy(day, month +1, year));
+    result = (gchar *)g_malloc(sizeof(gchar) * 24);/* improved from 12 to 24 - Luc A., 27 déc 2017 */
+    g_date_strftime(result, 23, "%d %b %Y", g_date_new_dmy(day, month +1, year));/* modifiyed from 11 to 23 - year with 4 digits  Luc A., 27 déc 2017 */
   } else {
     gtk_widget_destroy(calendarDialog);
   }
@@ -423,7 +478,7 @@ gboolean test_regexp(gchar *regexp, guint flags, gchar *error)
     dialog = gtk_message_dialog_new (GTK_WINDOW(window1),
                                      GTK_DIALOG_DESTROY_WITH_PARENT,
                                      GTK_MESSAGE_ERROR,
-                                     GTK_BUTTONS_CLOSE,
+                                     GTK_BUTTONS_CLOSE,"%s",
                                      msg);
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
