@@ -30,6 +30,62 @@ const gchar *G_EXE_LIST[G_EXE_LIST_MAX_DEPTH][G_EXE_LIST_MAX_WIDTH] = {
   {"nautilus", "iexplore", NULL}
 };
 
+/* thanks to : https://unicodebook.readthedocs.io/guess_encoding.html Luc A feb 2018*/
+const char *UTF_16_BE_BOM = "\xFE\xFF";
+const char *UTF_16_LE_BOM = "\xFF\xFE";
+const char *UTF_8_BOM = "\xEF\xBB\xBF";
+const char *UTF_32_BE_BOM = "\x00\x00\xFE\xFF";
+const char *UTF_32_LE_BOM = "\xFF\xFE\x00\x00";
+
+/***********************************
+  escape all spaces chars within
+  a path or filename
+  the entry string isn't freed, and a new string is allocated
+  Luc A - feb 2018
+***********************************/
+gchar *remove_spaces(const gchar *str)
+{
+ gchar *str2 =NULL;
+ gint i=0;
+ gint j=1;
+
+ if(strlen(str)==0)
+   return str2;
+ for(i=0;i<=strlen(str);i++)
+   {
+     if(str[i]==' ')
+       {
+         str2 = (gchar*)g_realloc(str2,j*sizeof(gchar));
+         str2[j-1]='\\';
+         j++;
+         str2 = (gchar*)g_realloc(str2,j*sizeof(gchar));
+         str2[j-1]=' ';
+         j++;
+       }
+     else
+       {
+         str2 = (gchar*)g_realloc(str2,j*sizeof(gchar));
+         str2[j-1]=str[i];
+         j++;
+       }
+   } 
+ str2[j-1]='\0';
+ return str2;
+}
+
+/* *********************************
+   function to get a valid file name
+   in the $TEMPDIR system repertory
+
+***********************************/
+gchar *GetTempFileName(gchar *fileSchema)
+{
+ gchar *tmpFile = NULL;
+
+ tmpFile = tempnam(NULL, fileSchema );
+ return tmpFile;
+}
+
 /*
  * Internal helper: save results to CSV.
  * Iterates through table results (if any), and then returns a CSV string
@@ -198,7 +254,7 @@ void saveResults(GtkWidget *widget)
         errMsg = gtk_message_dialog_new(GTK_WINDOW(dialog),
                                         (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
                                         GTK_MESSAGE_ERROR,
-                                        GTK_BUTTONS_OK,
+                                        GTK_BUTTONS_OK,"%s",
                                         error->message);
         gtk_dialog_run(GTK_DIALOG(errMsg));
         gtk_widget_destroy(errMsg);
@@ -281,7 +337,7 @@ void importCriteria(GtkWidget *widget)
         warnDialog = gtk_message_dialog_new(GTK_WINDOW(import),
                                             (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
                                             GTK_MESSAGE_ERROR,
-                                            GTK_BUTTONS_OK,
+                                            GTK_BUTTONS_OK,"%s",
                                             error->message);
         gtk_dialog_run(GTK_DIALOG(warnDialog));
         g_error_free(error);
@@ -387,7 +443,7 @@ void exportCriteria(GtkWidget *widget)
         warnDialog = gtk_message_dialog_new(GTK_WINDOW(export),
                                             (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
                                             GTK_MESSAGE_ERROR,
-                                            GTK_BUTTONS_OK,
+                                            GTK_BUTTONS_OK,"%s",
                                             error->message);
         g_error_free(error);
         error = NULL;
@@ -614,7 +670,12 @@ gboolean SMsyscall (const gchar *address, syscallType type)
   }
 
   /* Execute the command (replacing %f with filename) */
-  s1 = replaceAttributeString(attributes, address);
+  /* we must escape spaces from filenames - Luc A Feb 2018*/
+  if( type==TEXTEDITOR_LIST)
+    s1 = replaceAttributeString(attributes,(gchar*) remove_spaces(address));
+    else 
+      s1 = replaceAttributeString(attributes, address);
+
   if (s1 != NULL) {
     s2 = g_strconcat(executable, s1, NULL);
     g_free(s1);
@@ -763,8 +824,9 @@ void deleteFile(GtkWidget *widget)
                                      (GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL),
                                      GTK_MESSAGE_INFO,
                                      GTK_BUTTONS_OK,
-                                     _("Cannot delete file as name was not selected."),
-                                     NULL);
+                                     "%s",
+                                     _("Cannot delete file as name was not selected.")
+                                     );
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy(dialog);
     return;
@@ -826,20 +888,45 @@ void copyFile(GtkWidget *widget)
                                      (GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL),
                                      GTK_MESSAGE_INFO,
                                      GTK_BUTTONS_OK,
-                                     _("Cannot copy full file name as name was not selected."),
-                                     NULL);
+                                     "%s",
+                                     _("Cannot copy full file name as name was not selected.")
+                                     );
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy(dialog);
   }  
 }
 
-
+gint check_bom(const char *data, size_t size)
+{
+    if (size >= 3) {
+        if (memcmp(data, UTF_8_BOM, 3) == 0)
+            return 1;
+    }
+    if (size >= 4) {
+        if (memcmp(data, UTF_32_LE_BOM, 4) == 0)
+            return 2;/*"UTF-32-LE";*/
+        if (memcmp(data, UTF_32_BE_BOM, 4) == 0)
+            return 2;/*"UTF-32-BE";*/
+    }
+    if (size >= 2) {
+        if (memcmp(data, UTF_16_LE_BOM, 2) == 0)
+            return 4;/*"UTF-16-LE";*/
+        if (memcmp(data, UTF_16_BE_BOM, 2) == 0)
+            return 4;/*"UTF-16-BE";*/
+    }
+    return 0;
+}
 
 /*
  * internal helper: Wrapper function for g_file_get_contents()
  * In addition to calling GTK library, the resulting text, if valid
  * is converted to UTF-8 from its native format (usually UTF-8 also)
  * to remove illegal charactors
+ * Luc A. 29 dec 2017 : this function is called from search.c module by the function 
+ * phaseTwoSearch()
+ * perhaps I can add here a parser/decoder for doc-x and ODT files ?
+ * in current lINUX distros, we dont' have to use g_str_escape() so I commented the code
+ *
  */
 gboolean g_file_get_contents2 (const gchar *filename,
                                gchar **contents,
@@ -848,18 +935,94 @@ gboolean g_file_get_contents2 (const gchar *filename,
 {
   gboolean retVal;
   gchar *retContents;
+  gsize bytes_read;
+  gsize bytes_written;
+  gchar *charset;
+  gint sBOM;
   
   retVal = g_file_get_contents(filename, contents, length, error);
+  /* now me must check if is it a valid UTF8 string ! Luc A Feb 2018 */
+ 
+  if (g_utf8_validate (*contents, *length, NULL)){
+                return TRUE;
+      }
+  else{/* the text isn't encoded in UTF8 - Luc A deb 2018 */
+         sBOM= check_bom(*contents,(intptr_t)length );
+         /* we're trying to get a valid charset */
+         /* if sBOM == NULL then isn't a UTF string, thus probablu an ISO */
+         /*  encoding = "ISO-8859-15" by default */
+         switch(sBOM)
+         {
+          case 0:
+          {
+             retContents = g_convert_with_fallback (*contents, *length, "UTF-8", "ISO-8859-1",
+                                           NULL, &bytes_read, &bytes_written, error);
+            if ((retContents == NULL)||(error)) {
+                  *contents = NULL;
+                  *length = 0;
+                  retVal = FALSE;
+                }
+             else {
+                    g_free(*contents);    
+                    *contents = retContents;
+                    *length = bytes_written;
+                    retVal = TRUE;
+                  }
+            break;
+          }
+         case 2:
+          {
+             retContents = g_convert_with_fallback (*contents, *length, "UTF-8", "UTF-32",
+                                           NULL, &bytes_read, &bytes_written, error);
 
+             if ((retContents == NULL)||(error)) {
+                  *contents = NULL;
+                  *length = 0;
+                  retVal = FALSE;
+                }
+             else {
+                    g_free(*contents);    
+                    *contents = retContents;
+                    *length = bytes_written;
+                    retVal = TRUE;
+                  }
+             break;
+            } 
+          case 4:
+            {
+            
+             retContents = g_convert_with_fallback (*contents, *length, "UTF-8", "UTF-16",
+                                           NULL, &bytes_read, &bytes_written, error);
+
+             if ((retContents == NULL)||(error)) {
+                  *contents = NULL;
+                  *length = 0;
+                  retVal = FALSE;
+                }
+             else {
+                    g_free(*contents);    
+                    *contents = retContents;
+                    *length = bytes_written;
+                    retVal = TRUE;
+                  }
+            } 
+         }/* end switch */
+         /* in other cases, we return Error - i.e empry string */
+       }/* else NOT UTF8 */
+  // printf("++++ je suis dans g_file_contents2() ****\n");
+  return retVal;
   /* Remove unknown ASCII */
+/* bugged : remove all accented chars in modern Linux, so i've commented, but leaved the code for documentation
+Luc A., 29 dec 2017
   if (retVal) {
     retContents = g_strescape(*contents, "\"\\\t\n\b\f\r");
+printf("contenu nettoyé:%s\n",retContents);
     g_free(*contents);
     *contents = retContents;
     *length = g_strlen(retContents);
   }
 
-  return retVal;
+  return retVal;*/
 
 #ifdef NOTYET
 /*
@@ -888,7 +1051,6 @@ gboolean g_file_get_contents2 (const gchar *filename,
       *length = bytes_written;
     }
   }
-
   return retVal;
 #endif /* NOTYET */
 }
@@ -977,7 +1139,7 @@ gchar *comboBoxReadCleanFolderName(GtkComboBox *combobox)
   gchar *retStr = NULL;
   
   /* Retrieve look-in directory, ensuring terminated with (extra?) directory separator */
-  tmpStr[0] = gtk_combo_box_get_active_text(combobox);
+  tmpStr[0] = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(combobox));
   g_assert(tmpStr[0] != NULL);
   tmpStr[1] = g_strconcat(tmpStr[0], G_DIR_SEPARATOR_S, NULL);
   g_assert(tmpStr[1] != NULL);
@@ -1019,7 +1181,7 @@ gchar *comboBoxReadCleanFolderName(GtkComboBox *combobox)
   gchar *retStr = NULL;
   gchar *tmpStr[3];
   gchar **test, **test2;
-  tmpStr[0] = gtk_combo_box_get_active_text(combobox);
+  tmpStr[0] = gtk_combo_box_text_get_active_text (combobox);
 
   /* Test that it is a proper filename */
   if (g_file_test (tmpStr[0], G_FILE_TEST_IS_DIR)) {
